pub struct BufferData { /* private fields */ }Trait Implementations
Sourceimpl<SubstrateParent> HasContextView<SubstrateParent> for BufferDatawhere
Instance<Inverter>: HasContextView<SubstrateParent>,
Node: HasContextView<SubstrateParent>,
impl<SubstrateParent> HasContextView<SubstrateParent> for BufferDatawhere
Instance<Inverter>: HasContextView<SubstrateParent>,
Node: HasContextView<SubstrateParent>,
Sourcetype ContextView = BufferDataView<Context<SubstrateParent>>
type ContextView = BufferDataView<Context<SubstrateParent>>
A view of object.
Sourcefn context_view(
&self,
__substrate_parent: &SubstrateParent,
) -> ContextView<Self, SubstrateParent>
fn context_view( &self, __substrate_parent: &SubstrateParent, ) -> ContextView<Self, SubstrateParent>
Creates a context view of the object given a parent context.
Sourceimpl HasNestedView for BufferDatawhere
Instance<Inverter>: HasNestedView,
Node: HasNestedView,
impl HasNestedView for BufferDatawhere
Instance<Inverter>: HasNestedView,
Node: HasNestedView,
Sourcetype NestedView = BufferDataView<Nested>
type NestedView = BufferDataView<Nested>
A view of the nested object. Read more
Sourcefn nested_view(&self, __substrate_parent: &InstancePath) -> NestedView<Self>
fn nested_view(&self, __substrate_parent: &InstancePath) -> NestedView<Self>
Creates a nested view of the object given a parent node.