pub struct BufferDataView<SubstrateV>where
Instance<Inverter>: HasView<SubstrateV>,
Node: HasView<SubstrateV>,{ /* private fields */ }Trait Implementations
Sourceimpl<SubstrateV> Clone for BufferDataView<SubstrateV>
impl<SubstrateV> Clone for BufferDataView<SubstrateV>
Sourceimpl<SubstrateV> FlatLen for BufferDataView<SubstrateV>
impl<SubstrateV> FlatLen for BufferDataView<SubstrateV>
Sourceimpl<SubstrateV, SubstrateF> Flatten<SubstrateF> for BufferDataView<SubstrateV>
impl<SubstrateV, SubstrateF> Flatten<SubstrateF> for BufferDataView<SubstrateV>
Sourceimpl<SubstrateParent> HasContextView<SubstrateParent> for BufferDataView<Nested>where
Instance<Inverter>: HasView<Nested> + HasView<Nested, View = NestedView<Instance<Inverter>>>,
Node: HasView<Nested> + HasView<Nested, View = NestedView<Node>>,
<Instance<Inverter> as HasView<Nested>>::View: HasNestedView<NestedView = <Instance<Inverter> as HasView<Nested>>::View> + Send + Sync + HasContextView<SubstrateParent>,
<Node as HasView<Nested>>::View: HasNestedView<NestedView = <Node as HasView<Nested>>::View> + Send + Sync + HasContextView<SubstrateParent>,
impl<SubstrateParent> HasContextView<SubstrateParent> for BufferDataView<Nested>where
Instance<Inverter>: HasView<Nested> + HasView<Nested, View = NestedView<Instance<Inverter>>>,
Node: HasView<Nested> + HasView<Nested, View = NestedView<Node>>,
<Instance<Inverter> as HasView<Nested>>::View: HasNestedView<NestedView = <Instance<Inverter> as HasView<Nested>>::View> + Send + Sync + HasContextView<SubstrateParent>,
<Node as HasView<Nested>>::View: HasNestedView<NestedView = <Node as HasView<Nested>>::View> + Send + Sync + HasContextView<SubstrateParent>,
Sourcetype ContextView = BufferDataView<(Nested, Context<SubstrateParent>)>
type ContextView = BufferDataView<(Nested, Context<SubstrateParent>)>
A view of object.
Sourcefn context_view(
&self,
__substrate_parent: &SubstrateParent,
) -> ContextView<Self, SubstrateParent>
fn context_view( &self, __substrate_parent: &SubstrateParent, ) -> ContextView<Self, SubstrateParent>
Creates a context view of the object given a parent context.
Sourceimpl HasNestedView for BufferDataView<Nested>where
Instance<Inverter>: HasView<Nested>,
Node: HasView<Nested>,
<Instance<Inverter> as HasView<Nested>>::View: HasNestedView<NestedView = <Instance<Inverter> as HasView<Nested>>::View> + Send + Sync + HasNestedView,
<Node as HasView<Nested>>::View: HasNestedView<NestedView = <Node as HasView<Nested>>::View> + Send + Sync + HasNestedView,
impl HasNestedView for BufferDataView<Nested>where
Instance<Inverter>: HasView<Nested>,
Node: HasView<Nested>,
<Instance<Inverter> as HasView<Nested>>::View: HasNestedView<NestedView = <Instance<Inverter> as HasView<Nested>>::View> + Send + Sync + HasNestedView,
<Node as HasView<Nested>>::View: HasNestedView<NestedView = <Node as HasView<Nested>>::View> + Send + Sync + HasNestedView,
Sourcetype NestedView = BufferDataView<Nested>
type NestedView = BufferDataView<Nested>
A view of the nested object. Read more
Sourcefn nested_view(&self, __substrate_parent: &InstancePath) -> NestedView<Self>
fn nested_view(&self, __substrate_parent: &InstancePath) -> NestedView<Self>
Creates a nested view of the object given a parent node.
Sourceimpl<SubstrateT, SubstrateS, SubstrateA> Save<SubstrateS, SubstrateA> for BufferDataView<(Nested, Context<SubstrateT>)>where
Instance<Inverter>: HasNestedContextView<SubstrateT>,
Node: HasNestedContextView<SubstrateT>,
<Instance<Inverter> as HasNestedContextView<SubstrateT>>::View: Save<SubstrateS, SubstrateA>,
<Node as HasNestedContextView<SubstrateT>>::View: Save<SubstrateS, SubstrateA>,
SubstrateS: Simulator,
SubstrateA: Analysis,
impl<SubstrateT, SubstrateS, SubstrateA> Save<SubstrateS, SubstrateA> for BufferDataView<(Nested, Context<SubstrateT>)>where
Instance<Inverter>: HasNestedContextView<SubstrateT>,
Node: HasNestedContextView<SubstrateT>,
<Instance<Inverter> as HasNestedContextView<SubstrateT>>::View: Save<SubstrateS, SubstrateA>,
<Node as HasNestedContextView<SubstrateT>>::View: Save<SubstrateS, SubstrateA>,
SubstrateS: Simulator,
SubstrateA: Analysis,
Sourcetype SaveKey = BufferDataView<NestedContextSaveKey<SubstrateT, SubstrateS, SubstrateA>>
type SaveKey = BufferDataView<NestedContextSaveKey<SubstrateT, SubstrateS, SubstrateA>>
The key type used to address the saved output within the analysis. Read more
Sourcetype Saved = BufferDataView<NestedContextSaved<SubstrateT, SubstrateS, SubstrateA>>
type Saved = BufferDataView<NestedContextSaved<SubstrateT, SubstrateS, SubstrateA>>
The saved data associated with things object.
Sourcefn save(
&self,
__substrate_ctx: &SimulationContext<SubstrateS>,
__substrate_opts: &mut <SubstrateS as Simulator>::Options,
) -> <Self as Save<SubstrateS, SubstrateA>>::SaveKey
fn save( &self, __substrate_ctx: &SimulationContext<SubstrateS>, __substrate_opts: &mut <SubstrateS as Simulator>::Options, ) -> <Self as Save<SubstrateS, SubstrateA>>::SaveKey
Marks the given output for saving, returning a key that can be used to recover
the output once the simulation is complete.
Sourcefn from_saved(
__substrate_output: &<SubstrateA as Analysis>::Output,
__substrate_key: &<Self as Save<SubstrateS, SubstrateA>>::SaveKey,
) -> <Self as Save<SubstrateS, SubstrateA>>::Saved
fn from_saved( __substrate_output: &<SubstrateA as Analysis>::Output, __substrate_key: &<Self as Save<SubstrateS, SubstrateA>>::SaveKey, ) -> <Self as Save<SubstrateS, SubstrateA>>::Saved
Recovers the desired simulation output from the analysis’s output.
Sourceimpl<SubstrateT, SubstrateS, SubstrateA> Save<SubstrateS, SubstrateA> for BufferDataView<Context<SubstrateT>>where
Instance<Inverter>: HasContextView<SubstrateT>,
Node: HasContextView<SubstrateT>,
<Instance<Inverter> as HasContextView<SubstrateT>>::ContextView: Save<SubstrateS, SubstrateA>,
<Node as HasContextView<SubstrateT>>::ContextView: Save<SubstrateS, SubstrateA>,
SubstrateS: Simulator,
SubstrateA: Analysis,
impl<SubstrateT, SubstrateS, SubstrateA> Save<SubstrateS, SubstrateA> for BufferDataView<Context<SubstrateT>>where
Instance<Inverter>: HasContextView<SubstrateT>,
Node: HasContextView<SubstrateT>,
<Instance<Inverter> as HasContextView<SubstrateT>>::ContextView: Save<SubstrateS, SubstrateA>,
<Node as HasContextView<SubstrateT>>::ContextView: Save<SubstrateS, SubstrateA>,
SubstrateS: Simulator,
SubstrateA: Analysis,
Sourcetype SaveKey = BufferDataView<ContextSaveKey<SubstrateT, SubstrateS, SubstrateA>>
type SaveKey = BufferDataView<ContextSaveKey<SubstrateT, SubstrateS, SubstrateA>>
The key type used to address the saved output within the analysis. Read more
Sourcetype Saved = BufferDataView<ContextSaved<SubstrateT, SubstrateS, SubstrateA>>
type Saved = BufferDataView<ContextSaved<SubstrateT, SubstrateS, SubstrateA>>
The saved data associated with things object.
Sourcefn save(
&self,
__substrate_ctx: &SimulationContext<SubstrateS>,
__substrate_opts: &mut <SubstrateS as Simulator>::Options,
) -> <Self as Save<SubstrateS, SubstrateA>>::SaveKey
fn save( &self, __substrate_ctx: &SimulationContext<SubstrateS>, __substrate_opts: &mut <SubstrateS as Simulator>::Options, ) -> <Self as Save<SubstrateS, SubstrateA>>::SaveKey
Marks the given output for saving, returning a key that can be used to recover
the output once the simulation is complete.
Sourcefn from_saved(
__substrate_output: &<SubstrateA as Analysis>::Output,
__substrate_key: &<Self as Save<SubstrateS, SubstrateA>>::SaveKey,
) -> <Self as Save<SubstrateS, SubstrateA>>::Saved
fn from_saved( __substrate_output: &<SubstrateA as Analysis>::Output, __substrate_key: &<Self as Save<SubstrateS, SubstrateA>>::SaveKey, ) -> <Self as Save<SubstrateS, SubstrateA>>::Saved
Recovers the desired simulation output from the analysis’s output.
Sourceimpl<SubstrateS, SubstrateA> Save<SubstrateS, SubstrateA> for BufferDataView<Nested>
impl<SubstrateS, SubstrateA> Save<SubstrateS, SubstrateA> for BufferDataView<Nested>
Sourcetype SaveKey = BufferDataView<NestedSaveKey<SubstrateS, SubstrateA>>
type SaveKey = BufferDataView<NestedSaveKey<SubstrateS, SubstrateA>>
The key type used to address the saved output within the analysis. Read more
Sourcetype Saved = BufferDataView<NestedSaved<SubstrateS, SubstrateA>>
type Saved = BufferDataView<NestedSaved<SubstrateS, SubstrateA>>
The saved data associated with things object.
Sourcefn save(
&self,
__substrate_ctx: &SimulationContext<SubstrateS>,
__substrate_opts: &mut <SubstrateS as Simulator>::Options,
) -> <Self as Save<SubstrateS, SubstrateA>>::SaveKey
fn save( &self, __substrate_ctx: &SimulationContext<SubstrateS>, __substrate_opts: &mut <SubstrateS as Simulator>::Options, ) -> <Self as Save<SubstrateS, SubstrateA>>::SaveKey
Marks the given output for saving, returning a key that can be used to recover
the output once the simulation is complete.
Sourcefn from_saved(
__substrate_output: &<SubstrateA as Analysis>::Output,
__substrate_key: &<Self as Save<SubstrateS, SubstrateA>>::SaveKey,
) -> <Self as Save<SubstrateS, SubstrateA>>::Saved
fn from_saved( __substrate_output: &<SubstrateA as Analysis>::Output, __substrate_key: &<Self as Save<SubstrateS, SubstrateA>>::SaveKey, ) -> <Self as Save<SubstrateS, SubstrateA>>::Saved
Recovers the desired simulation output from the analysis’s output.