pub struct BufferDataWithMetadata { /* private fields */ }Trait Implementations
Sourceimpl<SubstrateParent> HasContextView<SubstrateParent> for BufferDataWithMetadatawhere
Instance<Inverter>: HasContextView<SubstrateParent>,
MyMetadata: HasContextView<SubstrateParent>,
impl<SubstrateParent> HasContextView<SubstrateParent> for BufferDataWithMetadatawhere
Instance<Inverter>: HasContextView<SubstrateParent>,
MyMetadata: HasContextView<SubstrateParent>,
Sourcetype ContextView = BufferDataWithMetadataView<Context<SubstrateParent>>
type ContextView = BufferDataWithMetadataView<Context<SubstrateParent>>
A view of object.
Sourcefn context_view(
&self,
__substrate_parent: &SubstrateParent,
) -> ContextView<Self, SubstrateParent>
fn context_view( &self, __substrate_parent: &SubstrateParent, ) -> ContextView<Self, SubstrateParent>
Creates a context view of the object given a parent context.
Sourceimpl HasNestedView for BufferDataWithMetadatawhere
Instance<Inverter>: HasNestedView,
MyMetadata: HasNestedView,
impl HasNestedView for BufferDataWithMetadatawhere
Instance<Inverter>: HasNestedView,
MyMetadata: HasNestedView,
Sourcetype NestedView = BufferDataWithMetadataView<Nested>
type NestedView = BufferDataWithMetadataView<Nested>
A view of the nested object. Read more
Sourcefn nested_view(&self, __substrate_parent: &InstancePath) -> NestedView<Self>
fn nested_view(&self, __substrate_parent: &InstancePath) -> NestedView<Self>
Creates a nested view of the object given a parent node.